==> haskell-x509-store-1.6.7-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.7
id: x509-store-1.6.7-IaYtmm1Ft1tAkHt1zWNvJf
key: x509-store-1.6.7-IaYtmm1Ft1tAkHt1zWNvJf
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
abi: b1023283dee215bcea1e821b705d4cac
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
import-dirs: /usr/lib/ghc-8.6.3/site-local/x509-store-1.6.7
library-dirs: /usr/lib/ghc-8.6.3/site-local/x509-store-1.6.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/x509-store-1.6.7
hs-libraries: HSx509-store-1.6.7-IaYtmm1Ft1tAkHt1zWNvJf
depends:
    asn1-encoding-0.9.5-8DGTSlCpMwuHaTltq7NmTe
    asn1-types-0.3.2-AnHjQ7P6LgBJI1DPVLNnWq base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.25-5E9EuEAz1M1JrY25iIyNbL directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-Lqi6VhR8Z0iDPxKwkMLeLE
    x509-1.7.5-25z6s02L5duJQTIhupegUo
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-store-1.6.7-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.7
id: x509-store-1.6.7-8hqgwXELPjfCJnmk9WEKHb
key: x509-store-1.6.7-8hqgwXELPjfCJnmk9WEKHb
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
abi: 2f6ebb5347c127de89331d536aa8cb11
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
import-dirs: /usr/lib/ghc-8.6.3/site-local/x509-store-1.6.7
library-dirs: /usr/lib/ghc-8.6.3/site-local/x509-store-1.6.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/x509-store-1.6.7
hs-libraries: HSx509-store-1.6.7-8hqgwXELPjfCJnmk9WEKHb
depends:
    asn1-encoding-0.9.5-EPSC46dU07nBGaIHX06tDr
    asn1-types-0.3.2-EdI7V594nzACjvFXzyOVHH base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.25-5E9EuEAz1M1JrY25iIyNbL directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-Ja7fJbU67Td2dh891W3cvz
    x509-1.7.5-7ryMn5tBzvQ7TjJsDySGMm
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
